# NOT RUN {
## generating an example Mplus syntax referring to a R object with correlation data
data(example2) # loading fictional example correlation matrix
# generate and write Mplus input file in your workspace directory
Mplus_tsyn(N = 300, Cor = example2)
## Mplus syntax is now saved in the current workspace
################################################################
### clean up work directory
file.remove("example2.inp") # remove generated Mplus syntax from work dir.
file.remove("example2.dat") # remove generated cor. data from work dir.
# }
Run the code above in your browser using DataLab